/* Model file for the MinD/MinE example. 
*
*  A. Hellander 2008-12-14. 
*
*/

/* Ordering of the species:
   0 : MinD_c_atp
   1 : MinD_m
   2 : Min_e
   3 : MinDE
   4 : MinD_c_adp   
*/	

#include <stdlib.h>
#include "propensities.h"
#include "mex.h"

#define CYTOSOL  1
#define MEMBRANE 2

/* Rate constants. */
const double NA   = 6.022e23;
const double kd   = 0.0125;
const double kdd  = 9.0e6;
const double kde  = 5.56e7;
const double ke   = 0.7;
const double k_adp= 0.5;

 
/* Reaction propensities. */
double rFun1(const int *x, double vol, const double *data, int sd)
{
	if(sd == MEMBRANE) return kd*x[0]/0.041; 
	return 0.0;
}

double rFun2(const int *x, double vol, const double *data, int sd)
{
	if(sd == MEMBRANE) return kdd*1e-3*x[0]*x[1]/(NA*vol);
	return 0.0;
}

double rFun3(const int *x, double vol, const double *data, int sd)
{
   if(sd == MEMBRANE) return kde*1e-3*x[1]*x[2]/(NA*vol);
   return 0.0;
}

double rFun4(const int *x, double vol, const double *data, int sd)
{
  if(sd == MEMBRANE) return ke*x[3];
  return 0.0;
}

double rFun5(const int *x, double vol, const double *data, int sd)
{
 return k_adp*x[4];
}

PropensityFun *ALLOC_propensities(void)
{
  PropensityFun *ptr = MALLOC(sizeof(PropensityFun)*5);
  
  ptr[0]=rFun1;
  ptr[1]=rFun2;
  ptr[2]=rFun3;
  ptr[3]=rFun4;
  ptr[4]=rFun5;
    
  return ptr;
}

void FREE_propensities(PropensityFun* ptr)
{
  FREE(ptr);
}

